%define anolis_release 1
%bcond_without check

Name:           libarchive
Version:        3.7.4
Release:        %{anolis_release}%{?dist}
Summary:        A library for handling streaming archive formats

License:        BSD 2-Clause License AND BSD 2-clause NetBSD License BSD 2-Clause License
URL:            https://www.libarchive.org/
Source0:        https://www.libarchive.org/downloads/%{name}-%{version}.tar.xz

Patch0:         CVE-2024-20696.patch

BuildRequires:  bison
BuildRequires:  bzip2-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel
BuildRequires:  libxml2-devel
BuildRequires:  libzstd-devel
BuildRequires:  lz4-devel
BuildRequires:  openssl-devel
BuildRequires:  sharutils
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  make

%description
Libarchive is a programming library that can create and read several different
streaming archive formats, including most popular tar variants, several cpio
formats, and both BSD and GNU ar variants. It can also write shar archives and
read ISO9660 CDROM images and ZIP archives.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package -n bsdtar
Summary:        Manipulate tape archives
Requires:       %{name} = %{version}-%{release}

%description -n bsdtar
The bsdtar package contains standalone bsdtar utility split off regular
libarchive packages.


%package -n bsdcpio
Summary:        Copy files to and from archives
Requires:       %{name} = %{version}-%{release}

%description -n bsdcpio
The bsdcpio package contains standalone bsdcpio utility split off regular
libarchive packages.


%package -n bsdcat
Summary:        Expand files to standard output
Requires:       %{name} = %{version}-%{release}

%description -n bsdcat
The bsdcat program typically takes a filename as an argument or reads standard
input when used in a pipe.  In both cases decompressed data it written to
standard output.

%package -n bsdunzip
Summary:        Extract files from a ZIP archive
Requires:       %{name} = %{version}-%{release}

%description -n bsdunzip
The bsdunzip package contains standalone bsdunzip utility split off regular
libarchive packages. It is designed to provide an interface compatible with
Info-ZIP's.

%prep
%autosetup -p1


%build
%configure --disable-static
%make_build


%install
%make_install

replace ()
{
    filename=$1
    file=`basename "$filename"`
    binary=${file%%.*}
    pattern=${binary##bsd}

    awk "
        # replace the topic
        /^.Dt ${pattern^^} 1/ {
            print \".Dt ${binary^^} 1\";
            next;
        }
        # replace the first occurence of \"$pattern\" by \"$binary\"
        !stop && /^.Nm $pattern/ {
            print \".Nm $binary\" ;
            stop = 1 ;
            next;
        }
        # print remaining lines
        1;
    " "$filename" > "$filename.new"
    mv "$filename".new "$filename"
}

for manpage in bsdtar.1 bsdcpio.1
do
    installed_manpage=`find "$RPM_BUILD_ROOT" -name "$manpage"`
    replace "$installed_manpage"
done

%generate_compatibility_deps

%check
%if %{with check}
logfiles ()
{
    find -name '*_test.log' -or -name test-suite.log
}

tempdirs ()
{
    cat `logfiles` \
        | awk "match(\$0, /[^[:space:]]*`date -I`[^[:space:]]*/) { print substr(\$0, RSTART, RLENGTH); }" \
        | sort | uniq
}

cat_logs ()
{
    for i in `logfiles`
    do
        echo "=== $i ==="
        cat "$i"
    done
}

run_testsuite ()
{
    rc=0
    %make_build check -j1 || {
        # error happened - try to extract in koji as much info as possible
        cat_logs

        for i in `tempdirs`; do
            if test -d "$i" ; then
                find $i -printf "%p\n    ~> a: %a\n    ~> c: %c\n    ~> t: %t\n    ~> %s B\n"
                cat $i/*.log
            fi
        done
        return 1
    }
    cat_logs
}

run_testsuite
%endif


%files
%dir %{abidir}
%license COPYING
%{_libdir}/libarchive.so.13*
%{abidir}/libarchive.dump
%{_mandir}/*/cpio.*
%{_mandir}/*/mtree.*
%{_mandir}/*/tar.*

%files doc
%doc NEWS README.md

%files devel
%{_includedir}/*.h
%{_mandir}/*/archive*
%{_mandir}/*/libarchive*
%{_libdir}/libarchive.so
%{_libdir}/pkgconfig/libarchive.pc

%files -n bsdtar
%license COPYING
%doc NEWS README.md
%{_bindir}/bsdtar
%{abidir}/bsdtar-option.list
%{_mandir}/*/bsdtar*

%files -n bsdcpio
%license COPYING
%doc NEWS README.md
%{_bindir}/bsdcpio
%{abidir}/bsdcpio-option.list
%{_mandir}/*/bsdcpio*

%files -n bsdcat
%license COPYING
%doc NEWS README.md
%{_bindir}/bsdcat
%{abidir}/bsdcat-option.list
%{_mandir}/*/bsdcat*

%files -n bsdunzip
%license COPYING
%doc NEWS README.md
%{_bindir}/bsdunzip
%{_mandir}/*/bsdunzip*

%changelog
* Tue Jun 25 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.7.4-1
- CVE-2024-20696 and update to 3.7.4

* Sun Jul 30 2023 Funda Wang <fundawang@yeah.net> - 3.7.1-1
- New version 3.7.1

* Sat Dec 17 2022 Funda Wang <fundawang@yeah.net> - 3.6.2-2
- Add upstream fix for invalid requirements

* Sun Dec 11 2022 Funda Wang <fundawang@yeah.net> - 3.6.2-1
- New version 3.6.2

* Tue Nov 01 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.6.1-2
- optimise spec file & add doc package

* Mon Sep 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.6.1-1
- udpate to 3.6.1

* Tue Mar 08 2022 Jacob Wang <yungao.jacob@linux.alibaba.com> - 3.6.0-1
- Initial version from upstream 3.6.0
